@@ -15,9 +15,7 @@
 #  limitations under the License.
 
 import sys
-from ..cl_xml import xpath
-# import xml.dom.minidom
-from lxml import etree
+from ..cl_xml import xpath, str_to_xml_doc
 from .xml_xfce import xml_xfce
 from collections.abc import Iterable
 from copy import deepcopy
@@ -45,7 +43,8 @@ class xml_xfcepanel(xml_xfce):
 </panels>'''
         try:
             # self.doc = xml.dom.minidom.parseString(self.text)
-            self.doc = etree.XML(bytes(bytearray(self.text, encoding='utf-8')))
+            # self.doc = etree.XML(bytes(bytearray(self.text, encoding='utf-8')))
+            self.doc = str_to_xml_doc(self.text)
         except Exception:
             self.setError(_("The template content is not XML"))
             return False
@@ -62,7 +61,6 @@ class xml_xfcepanel(xml_xfce):
         xmlNode = xmlNewNode
         childNodes = list(xmlNode)
         nextOldNode = xmlOldNode
-        # if xmlNode.nodeType == xmlNode.ELEMENT_NODE:
         n = xmlNode
         flagArray = False
         nValue = ''
@@ -88,11 +86,11 @@ class xml_xfcepanel(xml_xfce):
                                 'action="drop")')
                 self.setError(textError)
                 return False
-        if xmlOldNode.getparent() is not None:
+        if xmlNewNode.getparent() is not None:
             findAttrStr = ""
             if attrName:
                 findAttrStr = "[%s]" % attrName
-            findPath = u"child::%s%s" % (path, findAttrStr)
+            findPath = "child::%s%s" % (path, findAttrStr)
             # Рабочая нода
             if flagRootNode:
                 workNode = xmlOldNode.getparent()
